.ddcu_wrapper label { width: auto; display: inline; margin: 0; padding: 0; float: none; line-height: normal; }
.ddcu_file_input, .ddcu_m_file_input { display: none; }
.ddcu_hidden { display: none !important; }

.ddcu_button { display: inline-block; text-decoration: none;
    color:white; background-color: #999999; margin: 0; padding: 6px 8px; cursor: pointer; border-radius: 4px; }
.ddcu_button:hover { background-color: black; }
.ddcu_choose_other_file, .ddcu_delete_file, .ddcu_m_marked_for_deletion, .ddcu_m_delete, .ddcu_m_cancel_deletion { margin-left: 16px; }

.ddcu_m_file_entry { margin-bottom: 1em; }
.ddcu_m_marked_for_deletion { font-style: italic; }
.ddcu_m_file_entry.ddcu_m_to_be_deleted .ddcu_m_filename { text-decoration: line-through; }

.ddcu_overlay { display: none; background-color: rgba(0,0,0,.7); align-items: center; justify-content: center;
    position: fixed; top: 0; right: 0; bottom: 0; left: 0; z-index: 10000; cursor: wait; }
.ddcu_overlay_text { color: white; font-size: 24px; font-weight: bold; text-align: center; }